@@ -267,7 +267,7 @@ class EmojiPickerUI(Gtk.Window):
             emoji_unicode_max=self._emoji_unicode_max,
             non_fully_qualified=self._non_fully_qualified)
         self._gettext_translations = {}
-        for language in itb_emoji.expand_languages(self._languages):
+        for language in itb_util.expand_languages(self._languages):
             mo_file = gettext.find(DOMAINNAME, languages=[language])
             if (mo_file
                     and
@@ -455,9 +455,9 @@ class EmojiPickerUI(Gtk.Window):
         self._read_recently_used()
 
         self._emoji_by_label = self._emoji_matcher.emoji_by_label()
-        expanded_languages = itb_emoji.expand_languages(self._languages)
-        # 'en_001' and 'es_419' are not very useful in the treeview to browse the
-        # languages, remove them from the list:
+        expanded_languages = itb_util.expand_languages(self._languages)
+        # 'en_001' and 'es_419' are not very useful in the treeview to
+        # browse the languages, remove them from the list:
         expanded_languages = [
             lang
             for lang in expanded_languages
@@ -495,7 +495,7 @@ class EmojiPickerUI(Gtk.Window):
         if _ARGS.debug:
             sys.stdout.write(
                 'expanded_languages  = %s\n'
-                %itb_emoji.expand_languages(self._languages)
+                %itb_util.expand_languages(self._languages)
                 + 'first_language_with_categories = %s\n'
                 %first_language_with_categories
                 + 'number_of_empty_languages = %s\n'
@@ -602,8 +602,7 @@ class EmojiPickerUI(Gtk.Window):
         ]
         if self._gettext_translations[language]:
             return self._gettext_translations[language].gettext(key)
-        else:
-            return key
+        return key
 
     def _emoji_descriptions(self, emoji):
         '''
@@ -619,7 +618,7 @@ class EmojiPickerUI(Gtk.Window):
         descriptions = []
         descriptions.append(
             ' '.join(['U+%X' %ord(character) for character in emoji]))
-        for language in itb_emoji.expand_languages(self._languages):
+        for language in itb_util.expand_languages(self._languages):
             names = self._emoji_matcher.names(emoji, language=language)
             description = '<b>%s</b>' %language
             description_empty = True
@@ -851,7 +850,7 @@ class EmojiPickerUI(Gtk.Window):
             except (PermissionError, SyntaxError, IndentationError):
                 import traceback
                 traceback.print_exc()
-            except Exception as exception:
+            except Exception as dummy_exception:
                 import traceback
                 traceback.print_exc()
             else: # no exception occured
@@ -872,8 +871,7 @@ class EmojiPickerUI(Gtk.Window):
             if self._font == '':
                 self._font = 'emoji'
         if ('fontsize' in options_dict
-                and (isinstance(options_dict['fontsize'], int)
-                     or isinstance(options_dict['fontsize'], float))):
+                and (isinstance(options_dict['fontsize'], (int, float)))):
             self._fontsize = options_dict['fontsize']
         if ('fallback' in options_dict
                 and (isinstance(options_dict['fallback'], bool))):
@@ -917,7 +915,7 @@ class EmojiPickerUI(Gtk.Window):
             except (PermissionError, SyntaxError, IndentationError):
                 import traceback
                 traceback.print_exc()
-            except Exception as exception:
+            except Exception as dummy_exception:
                 import traceback
                 traceback.print_exc()
             else: # no exception occured
@@ -973,10 +971,10 @@ class EmojiPickerUI(Gtk.Window):
                 ('', '', self._recently_used_label)):
             self._clear_flowbox()
 
-    def on_clear_recently_used_button_clicked(self, dummy_button):
+    def on_clear_recently_used_button_clicked(self, _button):
         '''
-        :param dummy_button: The “Clear recently used” button
-        :type dummy_button: Gtk.Button object
+        :param _button: The “Clear recently used” button
+        :type _button: Gtk.Button object
         '''
         if _ARGS.debug:
             sys.stdout.write('on_clear_recently_used_button_clicked()\n')
@@ -1027,6 +1025,34 @@ class EmojiPickerUI(Gtk.Window):
         self._selection_clipboard.store()
         self._selection_primary.store() # Does not work.
 
+    def _show_concise_emoji_description_in_header_bar(self, emoji):
+        '''
+        Show a concise description of an emoji in the header bar
+        of the program.
+
+        :param emoji: The emoji for which a description should be
+                      shown in the header bar.
+        :type emoji: String
+        '''
+        self._header_bar.set_title(emoji)
+        self._header_bar.set_subtitle('')
+        # Display the names of the emoji in the first language
+        # where names are available in the header bar title:
+        for language in itb_util.expand_languages(self._languages):
+            names = self._emoji_matcher.names(emoji, language=language)
+            if names:
+                self._header_bar.set_title(emoji + ' ' + ', '.join(names))
+                break
+        # Display the keywords of the emoji in the first language
+        # where keywords are available in the header bar subtitle:
+        for language in itb_util.expand_languages(self._languages):
+            keywords = self._emoji_matcher.keywords(emoji, language=language)
+            if keywords:
+                self._header_bar.set_subtitle(
+                    self._translate_key('Keywords', language) + ': '
+                    + ', '.join(keywords))
+                break
+
     def _print_profiling_information(self):
         '''
         Print some profiling information to stdout.
@@ -1056,12 +1082,12 @@ class EmojiPickerUI(Gtk.Window):
             self._print_profiling_information()
         Gtk.main_quit()
 
-    def on_main_window_key_press_event(self, dummy_window, event_key):
+    def on_main_window_key_press_event(self, _window, event_key):
         '''
         Some key has been typed into the main window
 
-        :param dummy_window: The main window
-        :type dummy_window: Gtk.Window object
+        :param _window: The main window
+        :type _window: Gtk.Window object
         :param event_key:
         :type event_key: Gdk.EventKey object
         '''
@@ -1120,79 +1146,19 @@ class EmojiPickerUI(Gtk.Window):
                 Gtk.main_iteration()
         self._search_bar.handle_event(event_key)
 
-    def on_close_aboutdialog( # pylint: disable=no-self-use
-            self, about_dialog, dummy_response):
-        '''
-        The “About” dialog has been closed by the user
-
-        :param about_dialog: The “About” dialog
-        :type about_dialog: GtkDialog object
-        :param dummy_response: The response when the “About” dialog was closed
-        :type dummy_response: Gtk.ResponseType enum
-        '''
-        about_dialog.destroy()
-
-    def on_about_button_clicked(self, dummy_button):
+    def on_about_button_clicked(self, _button):
         '''
         The “About” button has been clicked
 
-        :param dummy_button: The “About” button
-        :type dummy_button: Gtk.Button object
+        :param _button: The “About” button
+        :type _button: Gtk.Button object
         '''
         if _ARGS.debug:
             sys.stdout.write('on_about_button_clicked()\n')
         if GTK_VERSION >= (3, 22, 0):
             self._main_menu_popover.popdown()
         self._main_menu_popover.hide()
-        aboutdialog = Gtk.AboutDialog()
-        # An empty string in aboutdialog.set_logo_icon_name('')
-        # prevents an ugly default icon to be shown. We don’t yet
-        # have nice icons for ibus-typing-booster.
-        aboutdialog.set_logo_icon_name('')
-        aboutdialog.set_title(
-            '🚀 ibus-typing-booster %s' %version.get_version())
-        aboutdialog.set_program_name(
-            '🚀 ibus-typing-booster')
-        aboutdialog.set_version(version.get_version())
-        aboutdialog.set_comments(
-            'A completion input method to speedup typing')
-        aboutdialog.set_copyright(
-            'Copyright © 2017 Mike FABIAN')
-        aboutdialog.set_authors([
-            'Mike FABIAN <maiku.fabian@gmail.com>',
-            'Anish Patil <anish.developer@gmail.com>',
-            ])
-        aboutdialog.set_translator_credits(
-            # Translators: put your names here, one name per line.
-            _('translator-credits'))
-        # aboutdialog.set_artists('')
-        aboutdialog.set_documenters([
-            'Mike FABIAN <maiku.fabian@gmail.com>',
-            ])
-        aboutdialog.set_website(
-            'http://mike-fabian.github.io/ibus-typing-booster')
-        aboutdialog.set_website_label(
-            'http://mike-fabian.github.io/ibus-typing-booster')
-        aboutdialog.set_license('''
-        This program is free software: you can redistribute it and/or modify
-        it under the terms of the GNU General Public License as published by
-        the Free Software Foundation, either version 3 of the License, or
-        (at your option) any later version.
-
-        This program is distributed in the hope that it will be useful,
-        but WITHOUT ANY WARRANTY; without even the implied warranty of
-        MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-        GNU General Public License for more details.
-
-        You should have received a copy of the GNU General Public License
-        along with this program.  If not, see <http://www.gnu.org/licenses/>
-        ''')
-        aboutdialog.set_wrap_license(True)
-        # overrides the above .set_license()
-        aboutdialog.set_license_type(Gtk.License.GPL_3_0)
-        aboutdialog.connect('response', self.on_close_aboutdialog)
-        aboutdialog.set_transient_for(self)
-        aboutdialog.show()
+        itb_util.ItbAboutDialog()
 
     def _fill_flowbox_with_search_results(self):
         '''
@@ -1471,6 +1437,7 @@ class EmojiPickerUI(Gtk.Window):
         (emoji, name) = self._parse_emoji_and_name_from_text(text)
         if not emoji:
             return Gdk.EVENT_PROPAGATE
+        self._show_concise_emoji_description_in_header_bar(emoji)
         self._set_clipboards(emoji)
         self._add_to_recently_used(emoji)
         self._emoji_selected_popover = Gtk.Popover()
@@ -1490,7 +1457,7 @@ class EmojiPickerUI(Gtk.Window):
         self._emoji_selected_popover.show_all()
         GLib.timeout_add(500, self._emoji_selected_popover_popdown)
 
-    def on_emoji_selected(self, dummy_flowbox, flowbox_child):
+    def on_emoji_selected(self, _flowbox, flowbox_child):
         '''
         Signal handler for selecting an emoji in the flowbox
         via the flowbox selection
@@ -1499,8 +1466,8 @@ class EmojiPickerUI(Gtk.Window):
         skin tone popovers. In that case, emoji selection is handled
         in on_flowbox_event_box_button_release() instead.
 
-        :param dummy_flowbox: The flowbox displaying the Emoji
-        :type dummy_flowbox: Gtk.FlowBox object
+        :param _flowbox: The flowbox displaying the Emoji
+        :type _flowbox: Gtk.FlowBox object
         :param flowbox_child: The child object containing the selected emoji
         :type flowbox_child: Gtk.FlowBoxChild object
         '''
@@ -1510,12 +1477,12 @@ class EmojiPickerUI(Gtk.Window):
         self._emoji_event_box_selected(event_box)
         return Gdk.EVENT_PROPAGATE
 
-    def on_main_menu_button_clicked(self, dummy_button):
+    def on_main_menu_button_clicked(self, _button):
         '''
         The main menu button has been clicked
 
-        :param button: The main menu button
-        :type button: Gtk.Button object
+        :param _button: The main menu button
+        :type _button: Gtk.Button object
         '''
         if _ARGS.debug:
             sys.stdout.write('on_main_menu_button_clicked()\n')
@@ -1523,12 +1490,12 @@ class EmojiPickerUI(Gtk.Window):
             self._main_menu_popover.popup()
         self._main_menu_popover.show_all()
 
-    def on_toggle_search_button_clicked(self, dummy_button):
+    def on_toggle_search_button_clicked(self, _button):
         '''
         The search button in the header bar has been clicked
 
-        :param dummy_button: The search button
-        :type  dummy_button: Gtk.Button object
+        :param _button: The search button
+        :type  _button: Gtk.Button object
         '''
         if _ARGS.debug:
             sys.stdout.write('on_toggle_search_button_clicked()\n')
@@ -1578,12 +1545,12 @@ class EmojiPickerUI(Gtk.Window):
             self._skin_tone_popover = None
         return False
 
-    def on_skin_tone_selected(self, dummy_flowbox, flowbox_child):
+    def on_skin_tone_selected(self, _flowbox, flowbox_child):
         '''
         Signal handler for selecting a skin tone emoji
 
-        :param dummy_flowbox: The flowbox displaying the skin tone emoji
-        :type dummy_flowbox: Gtk.FlowBox object
+        :param _flowbox: The flowbox displaying the skin tone emoji
+        :type _flowbox: Gtk.FlowBox object
         :param flowbox_child: The child object containing the selected emoji
         :type flowbox_child: Gtk.FlowBoxChild object
         '''
@@ -1598,6 +1565,7 @@ class EmojiPickerUI(Gtk.Window):
         (emoji, dummy_name) = self._parse_emoji_and_name_from_text(text)
         if not emoji:
             return
+        self._show_concise_emoji_description_in_header_bar(emoji)
         self._set_clipboards(emoji)
         self._add_to_recently_used(emoji)
         self._skin_tone_selected_popover = Gtk.Popover()
@@ -2112,12 +2080,12 @@ class EmojiPickerUI(Gtk.Window):
                 %filter_text)
         self._fill_listbox_font(filter_text)
 
-    def on_font_selected(self, dummy_listbox, listbox_row):
+    def on_font_selected(self, _listbox, listbox_row):
         '''
         Signal handler for selecting a font
 
-        :param dummy_listbox: The list box used to select a font
-        :type dummy_listbox: Gtk.ListBox object
+        :param _listbox: The list box used to select a font
+        :type _listbox: Gtk.ListBox object
         :param listbox_row: A row containing a font name
         :type listbox_row: Gtk.ListBoxRow object
         '''
@@ -2142,12 +2110,12 @@ class EmojiPickerUI(Gtk.Window):
         self._busy_start()
         GLib.idle_add(self._change_flowbox_font)
 
-    def on_font_button_clicked(self, dummy_button):
+    def on_font_button_clicked(self, _button):
         '''
         The font button in the header bar has been clicked
 
-        :param dummy_button: The font button
-        :type dummy_button: Gtk.Button object
+        :param _button: The font button
+        :type _button: Gtk.Button object
         '''
         if _ARGS.debug:
             sys.stdout.write(
