@@ -4,7 +4,7 @@
 # ibus-typing-booster - A completion input method for IBus
 #
 # Copyright (c) 2011-2013 Anish Patil <apatil@redhat.com>
-# Copyright (c) 2012-2016 Mike FABIAN <mfabian@redhat.com>
+# Copyright (c) 2012-2018 Mike FABIAN <mfabian@redhat.com>
 #
 # This program is free software: you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -16,7 +16,9 @@
 # GNU General Public License for more details.
 #  You should have received a copy of the GNU General Public License
 # along with this program.  If not, see <http://www.gnu.org/licenses/>
-
+'''
+Module for ibus-typing-booster to access the sqlite3 databases
+'''
 import os
 import os.path as path
 import sys
@@ -33,34 +35,7 @@ DEBUG_LEVEL = int(0)
 
 USER_DATABASE_VERSION = '0.65'
 
-class ImeProperties:
-    def __init__(self, configfile_path=None):
-        '''
-        configfile_path is the full path to the config file, for example
-        “/usr/share/ibus-typing-booster/hunspell-tables/en_US.conf”
-        '''
-        self.ime_property_cache = {}
-        if os.path.exists(configfile_path) and os.path.isfile(configfile_path):
-            comment_patt = re.compile('^#')
-            with codecs.open(
-                configfile_path,
-                mode='r',
-                encoding='UTF-8') as file_handle:
-                for line in file_handle:
-                    if not comment_patt.match(line):
-                        attr, val = line.strip().split('=', 1)
-                        self.ime_property_cache[attr.strip()] = val.strip()
-        else:
-            sys.stderr.write(
-                "Error: ImeProperties: No such file: %s" %configfile_path)
-
-    def get(self, key):
-        if key in self.ime_property_cache:
-            return self.ime_property_cache[key]
-        else:
-            return None
-
-class tabsqlitedb:
+class TabSqliteDb:
     '''Phrase databases for ibus-typing-booster
 
     The phrases table in the database has columns with the names:
@@ -82,7 +57,7 @@ class tabsqlitedb:
     user_db: Database on disk where the phrases learned from the user are stored
         user_freq >= 1: The number of times the user has used this phrase
     '''
-    def __init__(self, config_filename='', user_db_file=''):
+    def __init__(self, user_db_file=''):
         global DEBUG_LEVEL
         try:
             DEBUG_LEVEL = int(os.getenv('IBUS_TYPING_BOOSTER_DEBUG_LEVEL'))
@@ -90,8 +65,7 @@ class tabsqlitedb:
             DEBUG_LEVEL = int(0)
         if DEBUG_LEVEL > 1:
             sys.stderr.write(
-                "tabsqlitedb.__init__(config_filename = %s, user_db_file = %s)\n"
-                %(config_filename, user_db_file))
+                "TabSqliteDb.__init__(user_db_file = %s)\n" %user_db_file)
         self.user_db_file = user_db_file
         if not self.user_db_file:
             self.user_db_file = path.join(
@@ -110,14 +84,7 @@ class tabsqlitedb:
 
         self.old_phrases = []
 
-        self.ime_properties = ImeProperties(config_filename)
-        self._language = self.ime_properties.get('language')
-        self._normalization_form_internal = 'NFD'
-
-        dictionary_names = [
-            x.replace('.dic', '').strip()
-            for x in self.ime_properties.get("hunspell_dict").split(',')]
-        self.hunspell_obj = hunspell_suggest.Hunspell(dictionary_names)
+        self.hunspell_obj = hunspell_suggest.Hunspell(())
 
         if self.user_db_file != ':memory:':
             if not os.path.exists(self.user_db_file):
@@ -251,13 +218,13 @@ class tabsqlitedb:
         self.create_tables()
         if self.old_phrases:
             sqlargs = []
-            for x in self.old_phrases:
+            for ophrase in self.old_phrases:
                 sqlargs.append(
-                    {'input_phrase': x[0],
-                     'phrase': x[0],
+                    {'input_phrase': ophrase[0],
+                     'phrase': ophrase[0],
                      'p_phrase': '',
                      'pp_phrase': '',
-                     'user_freq': x[1],
+                     'user_freq': ophrase[1],
                      'timestamp': time.time()})
             sqlstr = '''
             INSERT INTO user_db.phrases (input_phrase, phrase, p_phrase, pp_phrase, user_freq, timestamp)
@@ -297,13 +264,13 @@ class tabsqlitedb:
             return
         input_phrase = itb_util.remove_accents(input_phrase)
         input_phrase = unicodedata.normalize(
-            self._normalization_form_internal, input_phrase)
+            itb_util.NORMALIZATION_FORM_INTERNAL, input_phrase)
         phrase = unicodedata.normalize(
-            self._normalization_form_internal, phrase)
+            itb_util.NORMALIZATION_FORM_INTERNAL, phrase)
         p_phrase = unicodedata.normalize(
-            self._normalization_form_internal, p_phrase)
+            itb_util.NORMALIZATION_FORM_INTERNAL, p_phrase)
         pp_phrase = unicodedata.normalize(
-            self._normalization_form_internal, pp_phrase)
+            itb_util.NORMALIZATION_FORM_INTERNAL, pp_phrase)
         sqlstr = '''
         UPDATE user_db.phrases
         SET user_freq = :user_freq, timestamp = :timestamp
@@ -318,9 +285,9 @@ class tabsqlitedb:
                    'timestamp': time.time()}
         if DEBUG_LEVEL > 1:
             sys.stderr.write(
-                "tabsqlitedb.update_phrase() sqlstr=%s\n" %sqlstr)
+                "TabSqliteDb.update_phrase() sqlstr=%s\n" %sqlstr)
             sys.stderr.write(
-                "tabsqlitedb.update_phrase() sqlargs=%s\n" %sqlargs)
+                "TabSqliteDb.update_phrase() sqlargs=%s\n" %sqlargs)
         try:
             self.db.execute(sqlstr, sqlargs)
             if commit:
@@ -334,13 +301,13 @@ class tabsqlitedb:
         '''
         if DEBUG_LEVEL > 1:
             sys.stderr.write(
-                "tabsqlitedb.sync_userdb() "
+                "TabSqliteDb.sync_userdb() "
                 + "commit and execute checkpoint ...\n")
         self.db.commit()
         self.db.execute('PRAGMA wal_checkpoint;')
         if DEBUG_LEVEL > 1:
             sys.stderr.write(
-                "tabsqlitedb.sync_userdb() "
+                "TabSqliteDb.sync_userdb() "
                 + "commit and execute checkpoint done.\n")
 
     def create_tables(self):
@@ -360,7 +327,7 @@ class tabsqlitedb:
         '''
         if DEBUG_LEVEL > 1:
             sys.stderr.write(
-                "tabsqlitedb.add_phrase() "
+                "TabSqliteDb.add_phrase() "
                 + "input_phrase=%s " % input_phrase.encode('UTF-8')
                 + "phrase=%s " % phrase.encode('UTF-8')
                 + "user_freq=%s " % user_freq
@@ -369,13 +336,13 @@ class tabsqlitedb:
             return
         input_phrase = itb_util.remove_accents(input_phrase)
         input_phrase = unicodedata.normalize(
-            self._normalization_form_internal, input_phrase)
+            itb_util.NORMALIZATION_FORM_INTERNAL, input_phrase)
         phrase = unicodedata.normalize(
-            self._normalization_form_internal, phrase)
+            itb_util.NORMALIZATION_FORM_INTERNAL, phrase)
         p_phrase = unicodedata.normalize(
-            self._normalization_form_internal, p_phrase)
+            itb_util.NORMALIZATION_FORM_INTERNAL, p_phrase)
         pp_phrase = unicodedata.normalize(
-            self._normalization_form_internal, pp_phrase)
+            itb_util.NORMALIZATION_FORM_INTERNAL, pp_phrase)
         select_sqlstr = '''
         SELECT * FROM user_db.phrases
         WHERE input_phrase = :input_phrase
@@ -404,9 +371,9 @@ class tabsqlitedb:
                           'timestamp': time.time()}
         if DEBUG_LEVEL > 1:
             sys.stderr.write(
-                "tabsqlitedb.add_phrase() insert_sqlstr=%s\n" %insert_sqlstr)
+                "TabSqliteDb.add_phrase() insert_sqlstr=%s\n" %insert_sqlstr)
             sys.stderr.write(
-                "tabsqlitedb.add_phrase() insert_sqlargs=%s\n" %insert_sqlargs)
+                "TabSqliteDb.add_phrase() insert_sqlargs=%s\n" %insert_sqlargs)
         try:
             self.db.execute(insert_sqlstr, insert_sqlargs)
             if commit:
@@ -415,6 +382,10 @@ class tabsqlitedb:
             traceback.print_exc()
 
     def optimize_database(self):
+        '''
+        Optimize the database by copying the contents
+        to temporary tables and back.
+        '''
         sqlstr = '''
             CREATE TABLE tmp AS SELECT * FROM %(database)s.phrases;
             DELETE FROM user_db.phrases;
@@ -437,6 +408,7 @@ class tabsqlitedb:
         self.db.commit()
 
     def create_indexes(self, commit=True):
+        '''Create indexes for the database.'''
         sqlstr = '''
         CREATE INDEX IF NOT EXISTS user_db.phrases_index_p ON phrases
         (input_phrase, id ASC);
@@ -464,14 +436,14 @@ class tabsqlitedb:
         [(phrase, user_freq), ...]
         '''
         input_phrase = unicodedata.normalize(
-            self._normalization_form_internal, input_phrase)
+            itb_util.NORMALIZATION_FORM_INTERNAL, input_phrase)
         p_phrase = unicodedata.normalize(
-            self._normalization_form_internal, p_phrase)
+            itb_util.NORMALIZATION_FORM_INTERNAL, p_phrase)
         pp_phrase = unicodedata.normalize(
-            self._normalization_form_internal, pp_phrase)
+            itb_util.NORMALIZATION_FORM_INTERNAL, pp_phrase)
         if DEBUG_LEVEL > 1:
             sys.stderr.write(
-                "tabsqlitedb.select_words() "
+                "TabSqliteDb.select_words() "
                 + "input_phrase=%s " % input_phrase.encode('UTF-8')
                 + "p_phrase=%s " % p_phrase.encode('UTF-8')
                 + "pp_phrase=%s\n" % pp_phrase.encode('UTF-8'))
@@ -480,7 +452,7 @@ class tabsqlitedb:
             x for x in self.hunspell_obj.suggest(input_phrase)])
         if DEBUG_LEVEL > 1:
             sys.stderr.write(
-                "tabsqlitedb.select_words() hunspell: best_candidates=%s\n"
+                "TabSqliteDb.select_words() hunspell: best_candidates=%s\n"
                 %self.best_candidates(phrase_frequencies))
         # Remove the accents *after* getting the hunspell candidates.
         # If the accents were removed before getting the hunspell candidates
@@ -492,7 +464,7 @@ class tabsqlitedb:
         # in the German hunspell dictionary would not find it either.
         input_phrase = itb_util.remove_accents(input_phrase)
         input_phrase = unicodedata.normalize(
-            self._normalization_form_internal, input_phrase)
+            itb_util.NORMALIZATION_FORM_INTERNAL, input_phrase)
         # Now phrase_frequencies might contain something like this:
         #
         # {'code': 0, 'communicability': 0, 'cold': 0, 'colour': 0}
@@ -563,7 +535,7 @@ class tabsqlitedb:
             phrase_frequencies.update([(x[0], x[1]/float(count))])
         if DEBUG_LEVEL > 1:
             sys.stderr.write(
-                "tabsqlitedb.select_words() Unigram best_candidates=%s\n"
+                "TabSqliteDb.select_words() Unigram best_candidates=%s\n"
                 %self.best_candidates(phrase_frequencies))
         if not p_phrase:
             # If no context for bigram matching is available, return
@@ -597,7 +569,7 @@ class tabsqlitedb:
                   +0.5*phrase_frequencies[x[0]])])
         if DEBUG_LEVEL > 1:
             sys.stderr.write(
-                "tabsqlitedb.select_words() Bigram best_candidates=%s\n"
+                "TabSqliteDb.select_words() Bigram best_candidates=%s\n"
                 %self.best_candidates(phrase_frequencies))
         if not pp_phrase:
             # If no context for trigram matching is available, return
@@ -635,11 +607,16 @@ class tabsqlitedb:
                   +0.5*phrase_frequencies[x[0]])])
         if DEBUG_LEVEL > 1:
             sys.stderr.write(
-                "tabsqlitedb.select_words() Trigram best_candidates=%s\n"
+                "TabSqliteDb.select_words() Trigram best_candidates=%s\n"
                 %self.best_candidates(phrase_frequencies))
         return self.best_candidates(phrase_frequencies)
 
     def generate_userdb_desc(self):
+        '''
+        Add a description table to the user database
+
+        This adds the database version and  the create time
+        '''
         try:
             sqlstring = ('CREATE TABLE IF NOT EXISTS user_db.desc '
                          + '(name PRIMARY KEY, value);')
@@ -655,6 +632,9 @@ class tabsqlitedb:
             traceback.print_exc()
 
     def init_user_db(self):
+        '''
+        Initialize the user database unless it is an in-memory database
+        '''
         if self.user_db_file == ':memory:':
             return
         if not path.exists(self.user_db_file):
@@ -734,10 +714,10 @@ CREATE TABLE phrases (id INTEGER PRIMARY KEY, input_phrase TEXT, phrase TEXT, p_
         sqlargs = {'freq': itb_util.SHORTCUT_USER_FREQ}
         if DEBUG_LEVEL > 1:
             sys.stderr.write(
-                "tabsqlitedb.list_user_shortcuts() sqlstr=%s\n"
+                "TabSqliteDb.list_user_shortcuts() sqlstr=%s\n"
                 %sqlstr)
             sys.stderr.write(
-                "tabsqlitedb.list_user_shortcuts() sqlargs=%s\n"
+                "TabSqliteDb.list_user_shortcuts() sqlargs=%s\n"
                 %sqlargs)
         result = self.db.execute(sqlstr, sqlargs).fetchall()
         if DEBUG_LEVEL > 1:
@@ -758,18 +738,18 @@ CREATE TABLE phrases (id INTEGER PRIMARY KEY, input_phrase TEXT, phrase TEXT, p_
         if not phrase:
             return
         phrase = unicodedata.normalize(
-            self._normalization_form_internal, phrase)
+            itb_util.NORMALIZATION_FORM_INTERNAL, phrase)
         p_phrase = unicodedata.normalize(
-            self._normalization_form_internal, p_phrase)
+            itb_util.NORMALIZATION_FORM_INTERNAL, p_phrase)
         pp_phrase = unicodedata.normalize(
-            self._normalization_form_internal, pp_phrase)
+            itb_util.NORMALIZATION_FORM_INTERNAL, pp_phrase)
         input_phrase = itb_util.remove_accents(input_phrase)
         input_phrase = unicodedata.normalize(
-            self._normalization_form_internal, input_phrase)
+            itb_util.NORMALIZATION_FORM_INTERNAL, input_phrase)
 
         if DEBUG_LEVEL > 1:
             sys.stderr.write(
-                "tabsqlitedb.check_phrase_and_update_frequency() "
+                "TabSqliteDb.check_phrase_and_update_frequency() "
                 + "phrase=%(p)s, input_phrase=%(t)s\n"
                 %{'p': phrase.encode('UTF-8'),
                   't': input_phrase.encode('UTF-8')})
@@ -794,16 +774,16 @@ CREATE TABLE phrases (id INTEGER PRIMARY KEY, input_phrase TEXT, phrase TEXT, p_
                    'pp_phrase': pp_phrase}
         if DEBUG_LEVEL > 1:
             sys.stderr.write(
-                "tabsqlitedb.check_phrase_and_update_frequency() sqlstr=%s\n"
+                "TabSqliteDb.check_phrase_and_update_frequency() sqlstr=%s\n"
                 %sqlstr)
             sys.stderr.write(
-                "tabsqlitedb.check_phrase_and_update_frequency() sqlargs=%s\n"
+                "TabSqliteDb.check_phrase_and_update_frequency() sqlargs=%s\n"
                 %sqlargs)
         result = self.db.execute(sqlstr, sqlargs).fetchall()
         if DEBUG_LEVEL > 1:
             sys.stderr.write(
                 "check_phrase_and_update_frequency() result=%s\n" %result)
-        if len(result) > 0:
+        if result:
             # A match was found in user_db, increase user frequency by
             # user_freq_increment (1 by default)
             self.update_phrase(input_phrase=input_phrase,
@@ -832,15 +812,15 @@ CREATE TABLE phrases (id INTEGER PRIMARY KEY, input_phrase TEXT, phrase TEXT, p_
         '''
         if DEBUG_LEVEL > 1:
             sys.stderr.write(
-                "tabsqlitedb.remove_phrase() phrase=%(p)s\n"
+                "TabSqliteDb.remove_phrase() phrase=%(p)s\n"
                 %{'p': phrase.encode('UTF-8')})
         if not phrase:
             return
         phrase = unicodedata.normalize(
-            self._normalization_form_internal, phrase)
+            itb_util.NORMALIZATION_FORM_INTERNAL, phrase)
         if input_phrase:
             input_phrase = unicodedata.normalize(
-                self._normalization_form_internal, input_phrase)
+                itb_util.NORMALIZATION_FORM_INTERNAL, input_phrase)
         if input_phrase:
             delete_sqlstr = '''
             DELETE FROM user_db.phrases
@@ -867,7 +847,7 @@ CREATE TABLE phrases (id INTEGER PRIMARY KEY, input_phrase TEXT, phrase TEXT, p_
             db.close()
             phrases = [
                 (unicodedata.normalize(
-                    self._normalization_form_internal, x[0]), x[1])
+                    itb_util.NORMALIZATION_FORM_INTERNAL, x[0]), x[1])
                 for x in
                 phrases
             ]
@@ -877,6 +857,12 @@ CREATE TABLE phrases (id INTEGER PRIMARY KEY, input_phrase TEXT, phrase TEXT, p_
             return []
 
     def read_training_data_from_file(self, filename):
+        '''
+        Read data to train the prediction from a text file.
+
+        :param filename: Full path of the text file to read.
+        :type filename: String
+        '''
         if not os.path.isfile(filename):
             return False
         rows = self.db.execute(
@@ -894,25 +880,31 @@ CREATE TABLE phrases (id INTEGER PRIMARY KEY, input_phrase TEXT, phrase TEXT, p_
                                     'user_freq': x[4],
                                     'timestamp': x[5]}
                                   )])
-        with codecs.open(filename, encoding='UTF-8') as file_handle:
-            lines = [
-                unicodedata.normalize(self._normalization_form_internal, x)
-                for x in file_handle.readlines()]
-            for line in lines:
-                for token in itb_util.tokenize(line):
-                    key = (token, token, p_token, pp_token)
-                    if key in database_dict:
-                        database_dict[key]['user_freq'] += 1
-                        database_dict[key]['timestamp'] = time.time()
-                    else:
-                        database_dict[key] = {'input_phrase': token,
-                                              'phrase': token,
-                                              'p_phrase': p_token,
-                                              'pp_phrase': pp_token,
-                                              'user_freq': 1,
-                                              'timestamp': time.time()}
-                    pp_token = p_token
-                    p_token = token
+        lines = []
+        try:
+            with codecs.open(filename, encoding='UTF-8') as file_handle:
+                lines = [
+                    unicodedata.normalize(
+                        itb_util.NORMALIZATION_FORM_INTERNAL, x)
+                    for x in file_handle.readlines()]
+        except:
+            traceback.print_exc()
+            return False
+        for line in lines:
+            for token in itb_util.tokenize(line):
+                key = (token, token, p_token, pp_token)
+                if key in database_dict:
+                    database_dict[key]['user_freq'] += 1
+                    database_dict[key]['timestamp'] = time.time()
+                else:
+                    database_dict[key] = {'input_phrase': token,
+                                          'phrase': token,
+                                          'p_phrase': p_token,
+                                          'pp_phrase': pp_token,
+                                          'user_freq': 1,
+                                          'timestamp': time.time()}
+                pp_token = p_token
+                p_token = token
         sqlargs = []
         for x in database_dict.keys():
             sqlargs.append(database_dict[x])
@@ -934,6 +926,10 @@ CREATE TABLE phrases (id INTEGER PRIMARY KEY, input_phrase TEXT, phrase TEXT, p_
         return True
 
     def remove_all_phrases(self):
+        '''
+        Remove all phrases from the database, i.e. delete all the
+        data learned from user input or text files.
+        '''
         try:
             self.db.execute('DELETE FROM phrases;')
             self.db.commit()
