@@ -4,7 +4,7 @@
 # ibus-typing-booster - A completion input method for IBus
 #
 # Copyright (c) 2012-2013 Anish Patil <apatil@redhat.com>
-# Copyright (c) 2012-2016 Mike FABIAN <mfabian@redhat.com>
+# Copyright (c) 2012-2018 Mike FABIAN <mfabian@redhat.com>
 #
 # This program is free software: you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -18,6 +18,22 @@
 #
 # You should have received a copy of the GNU General Public License
 # along with this program.  If not, see <http://www.gnu.org/licenses/>
-
+'''
+Contains functions to return the current version number
+and prefix of ibus-typing-booster.
+'''
 def get_version():
-    return "1.5.35"
+    '''
+    Returns the current version number of ibus-typing-booster.
+
+    :rtype: String
+    '''
+    return "2.1.2"
+
+def get_prefix():
+    '''
+    Returns the current prefix of ibus-typing-booster.
+
+    :rtype: String
+    '''
+    return '/usr'
